@@ -11,22 +11,26 @@ class SSH:
     def __init__(self, timeout: int = 300):
         self.timeout = timeout
 
-    def run(self, cmd):
+    def run(self, cmd: str, is_check: bool = False):
         """
         This method run shell commands
         :param cmd:
+        :param is_check:run check command
         :return:
         """
         try:
-            output = subprocess.check_output(
-                cmd,
-                stderr=subprocess.STDOUT,
-                shell=True, timeout=self.timeout,
-                universal_newlines=True)
+            if is_check:
+                output = subprocess.check_output(
+                    cmd,
+                    stderr=subprocess.STDOUT,
+                    shell=True, timeout=self.timeout,
+                    universal_newlines=False)
+            # execute cmd
+            else:
+                output = subprocess.getoutput(cmd)
             return output
         except subprocess.CalledProcessError as err:
-            return ''
-            #logger.error("subprocess Status : FAIL", err.returncode, err.output)
-            #raise SSHSubprocessError()
+            logger.error("subprocess Status : FAIL", err.returncode, err.output)
+            raise SSHSubprocessError()
         except Exception as err:
              raise err
