@@ -8,6 +8,10 @@ from benchmark_runner.main.environment_variables import environment_variables
 log_level = os.environ.get('log_level', 'INFO').upper()
 logger.setLevel(level=log_level)
 
+# venv
+# python -m venv venv
+# . venv/bin/activate
+
 
 @logger_time_stamp
 def main():
@@ -15,15 +19,15 @@ def main():
     The main
     """
     environment_variables_dict = environment_variables.environment_variables_dict
-    workload = environment_variables_dict.get('workload')
+    workload = environment_variables_dict.get('workload', '')
     # workload name validation
     if workload not in environment_variables.workloads_list:
         logger.info(f'Enter valid workload name {environment_variables.workloads_list}')
         raise Exception(f'Not valid workload name: {workload} \n, choose one from the list: {environment_variables.workloads_list}')
 
-    es_host = environment_variables_dict.get('elasticsearch')
-    es_port = environment_variables_dict.get('elasticsearch_port')
-    kubeadmin_password = environment_variables_dict.get('kubeadmin_password')
+    es_host = environment_variables_dict.get('elasticsearch', '')
+    es_port = environment_variables_dict.get('elasticsearch_port', '')
+    kubeadmin_password = environment_variables_dict.get('kubeadmin_password', '')
     benchmark_operator_workload = BenchmarkOperatorWorkloads(kubeadmin_password=kubeadmin_password, es_host=es_host, es_port=es_port, workload=workload)
     benchmark_operator_workload.run_workload()
 
